@@ -56,9 +56,9 @@ class app_flow_graph (stdgui.gui_flow_graph):
         
         input_rate = self.u.adc_freq () / self.u.decim_rate ()
 
-        block, fft_win = fftsink.make_fft_sink_c (self, panel, "", 512, input_rate)
-        self.connect (self.u, block)
-        vbox.Add (fft_win, 1, wx.EXPAND)
+        fft = fftsink.fft_sink_c (self, panel, fft_size=512, sample_rate=input_rate)
+        self.connect (self.u, fft)
+        vbox.Add (fft.win, 1, wx.EXPAND)
 
         # build small control area at bottom
         hbox = wx.BoxSizer (wx.HORIZONTAL)
