@@ -7,17 +7,25 @@ from optparse import OptionParser
 
 def main ():
     parser = OptionParser (option_class=eng_option)
-    parser.add_option ("-d", "--decim", type="eng_float", default=16,
+    parser.add_option ("-d", "--decim", type="int", default=16,
                        help="set fgpa decimation rate to DECIM")
-    parser.add_option ("-c", "--cordic-freq", type="eng_float", default=0,
-                       help="set Rx cordic frequency to FREQ", metavar="FREQ")
+    parser.add_option ("-c", "--ddc-freq", type="eng_float", default=0,
+                       help="set Rx ddc frequency to FREQ", metavar="FREQ")
+    parser.add_option ("-m", "--mux", type="intx", default=0x32103210,
+                       help="set fpga FR_RX_MUX register to MUX")
+    parser.add_option ("-g", "--gain", type="eng_float", default=0,
+                       help="set Rx PGA gain in dB (default 0 dB)")
     parser.add_option ("-o", "--output-file", default="usrp_rx.dat",
                        help="write data to FILE", metavar="FILE")
     (options, args) = parser.parse_args ()
 
     fg = gr.flow_graph ()
-    u = usrp.source_s (0, options.decim)
-    u.set_rx_freq (0, options.cordic_freq)
+
+    u = usrp.source_s (0, options.decim, 1, options.mux, 0)
+    u.set_rx_freq (0, options.ddc_freq)
+    u.set_pga (0, options.gain)
+    u.set_pga (1, options.gain)
+    
     dst = gr.file_sink (gr.sizeof_short, options.output_file)
     fg.connect (u, dst)
     
